Nav
====================

This module contains the Nav class, which is used to represent navigation meshes in Counter-Strike 2.

awpy.nav
------------------------------

.. automodule:: awpy.nav
   :members:
   :undoc-members:
   :show-inheritance: